# pyLattice
A python library for advanced lattice light-sheet image analysis

Welcome!

Please read the [manual](./docs/PyLattice_Manual.pdf) to get started.

![Logo](./docs/pyLattice_logo.png)


## Installation

clone or download the repository
```bash
pip install pylattice
pip install -r requirements.txt
cd source/jupyter
jupyter notebook
```
in browser open `source/jupyter/latticeFrame_showFrame.ipynb`

## Test data

A small test data set can be found here:
https://www.dropbox.com/sh/s7q45h7wqoco5hl/AAB2Tt5lTGSkF2VhMTMM8NEWa?dl=0

## FAQ

[Lattice Light-Sheet Microscopy](https://en.wikipedia.org/wiki/Lattice_light-sheet_microscopy)



## References

- scikit http://scikit-image.org
- ChimeraX https://www.cgl.ucsf.edu/chimerax/
- llsm tools https://github.com/francois-a/llsmtools
- utrack https://www.utsouthwestern.edu/labs/danuser/software/#utrack_ancs
- Joh Schöneberg http://www.schoeneberglab.org
- The Betzig Lab https://www.janelia.org/lab/betzig-lab
- The Drubin/Barnes Lab https://drubinbarneslab.berkeley.edu
